==> LL_utils-4.1.1.4-power-Linux-RHEL6.tar.gz: var/www/ll/cgi-bin/show_tab_panel_users.pl <==
#!/usr/bin/perl -wT

# static char sccsid[] = "@(#)43 1.10 src/ll/config_editor/cgi-bin/show_tab_panel_users.pl, ll.config, ll_rrur2, rrur21042a 1/2/10 03:58:34\n";

use strict;
use lib "/var/www/ll/cgi-bin";
use LLUtil;
use HTML::Template;
use DBI;

my ($mysql_host, $mysql_user, $mysql_pass, $mysql_db) = get_db_info(1);

my @normal_tables_by_userID = @{LLUtil::ALL_TABLES->{"tab_panel_users"}->[0]};

# Create a HTML::Template
use constant TMPL_FILE => LLUtil::TMPL_DIR."/show_tab_panel_users.tmpl";
my $tmpl = new HTML::Template(filename => TMPL_FILE);

# Connect to db
my $dbh = DBI->connect("DBI:mysql:database=$mysql_db;host=$mysql_host",$mysql_user,$mysql_pass);
if(!defined($dbh))
{
	print "Content-type: text/html\n\n";
	$tmpl->param(error_string => DBI->errstr);
	print $tmpl->output;
	exit 1;
}

# Get cluster id and name
my $primary_cluster_id;
my $sql_str="select clusterID,name from TLL_Cluster;";
my $sth=$dbh->prepare($sql_str);
if(!defined($sth->execute()))
{
	print "Content-type: text/html\n\n";
	$tmpl->param(error_string => $dbh->errstr);
	print $tmpl->output;
	exit 1;
}
my($id,$name);
$sth->bind_columns(undef,\$id,\$name);
my @pull_down_cluster=();
if($sth->fetch())
{
	$primary_cluster_id = $id;
	my %pair = (id => $id, name => $name);
	push @pull_down_cluster, \%pair;
	while($sth->fetch())
	{
		my %pair = (id => $id, name => $name);
		push @pull_down_cluster, \%pair;
	}
}
$tmpl->param(pull_down_cluster => \@pull_down_cluster);

# Get default user id and name
my $default_user_id = undef;

# Get user id and name
if(defined($primary_cluster_id))
{
	$sql_str="select userID,name from TLLS_CFGUser where clusterID=".$primary_cluster_id;
	$tmpl->param("TLLS_CFGUser-clusterID" => $primary_cluster_id);
}
else
{
	$sql_str="select userID,name from TLLS_CFGUser;";
	$tmpl->param("TLLS_CFGUser-clusterID" => 1);
}
$sth=$dbh->prepare($sql_str);
if(!defined($sth->execute()))
{
	print "Content-type: text/html\n\n";
	$tmpl->param(error_string => $dbh->errstr);
	print $tmpl->output;
	exit 1;
}
$sth->bind_columns(undef,\$id,\$name);
my @pull_down=();
while($sth->fetch())
{
	if($name eq "default" || $name eq "Default")
	{
		$default_user_id = $id;
	}

	my %pair = (id => $id, name => $name);
	push @pull_down, \%pair;
}
$tmpl->param(pull_down => \@pull_down);

# Show normal tables
foreach my $table (@normal_tables_by_userID)
{
	my @table_items = ();
	my $ary_ref = undef;
	if(defined($default_user_id))
	{
		$sql_str="select * from ".$table." where userID=".$default_user_id;
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			print "Content-type: text/html\n\n";
			$tmpl->param(error_string => $dbh->errstr);
			print $tmpl->output;
			exit 1;
		}
		
		$ary_ref = $sth->fetchrow_arrayref;
	}
	if(!defined($ary_ref))
	{
		$sql_str="select * from ".$table." limit 1";
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			print "Content-type: text/html\n\n";
			$tmpl->param(error_string => $dbh->errstr);
			print $tmpl->output;
			exit 1;
		}
	}

	for(my $m=1;$m<$sth->{NUM_OF_FIELDS};$m++)
	{
		if($sth->{NAME}->[$m] ne "clusterID")
		{
			my $default = "";
			if(defined($default_user_id) && defined($ary_ref) && exists $ary_ref->[$m])
			{
				$default = $ary_ref->[$m];
			}
			
			my %item = (id => $table."-".$sth->{NAME}->[$m],
				    name => $table."-".$sth->{NAME}->[$m],
				    title => $table."-".$sth->{NAME}->[$m],
				    display_name => $sth->{NAME}->[$m],
				    orig_id => "orig-".$table."-".$sth->{NAME}->[$m],
				    orig_name => "orig-".$table."-".$sth->{NAME}->[$m],
				    default => $default);
			push @table_items, \%item;
		}
	}
	$tmpl->param($table."_items" => \@table_items);
	$tmpl->param($table."-primary_key" => $sth->{NAME}->[0]);
	
}

$sth->finish();
$dbh->disconnect();


print "Content-type: text/html\n\n";
print $tmpl->output;

==> LL_utils-5.1.0.17-power-Linux-RHEL6.tar.gz: var/www/ll/cgi-bin/show_tab_panel_users.pl <==
#!/usr/bin/perl -wT

# static char sccsid[] = "@(#)43 1.11 src/ll/config_editor/cgi-bin/show_tab_panel_users.pl, ll.config, ll_rrnep2, rrnep21206a 9/26/10 16:37:43\n";

use strict;
use lib "/var/www/ll/cgi-bin";
use LLUtil;
use HTML::Template;
use DBI;

my ($db_host, $db_user, $db_pass, $db_db, $db_conn, $db2inst) = get_db_info(1);

my @normal_tables_by_userID = @{LLUtil::ALL_TABLES->{"tab_panel_users"}->[0]};

# Create a HTML::Template
use constant TMPL_FILE => LLUtil::TMPL_DIR."/show_tab_panel_users.tmpl";
my $tmpl = new HTML::Template(filename => TMPL_FILE);

# Connect to db
my $dbh = get_dbh(1);
if(!defined($dbh))
{
	error_and_exit($dbh->errstr);
}

# Get cluster id and name
my $primary_cluster_id;
my $sql_str="select clusterID,name from TLL_Cluster;";
my $sth=$dbh->prepare($sql_str);
if(!defined($sth->execute()))
{
	print "Content-type: text/html\n\n";
	$tmpl->param(error_string => $dbh->errstr);
	print $tmpl->output;
	exit 1;
}
my($id,$name);
$sth->bind_columns(undef,\$id,\$name);
my @pull_down_cluster=();
if($sth->fetch())
{
	$primary_cluster_id = $id;
	my %pair = (id => $id, name => $name);
	push @pull_down_cluster, \%pair;
	while($sth->fetch())
	{
		my %pair = (id => $id, name => $name);
		push @pull_down_cluster, \%pair;
	}
}
$tmpl->param(pull_down_cluster => \@pull_down_cluster);

# Get default user id and name
my $default_user_id = undef;

# Get user id and name
if(defined($primary_cluster_id))
{
	$sql_str="select userID,name from TLLS_CFGUser where clusterID=".$primary_cluster_id;
	$tmpl->param("TLLS_CFGUser-clusterID" => $primary_cluster_id);
}
else
{
	$sql_str="select userID,name from TLLS_CFGUser;";
	$tmpl->param("TLLS_CFGUser-clusterID" => 1);
}
$sth=$dbh->prepare($sql_str);
if(!defined($sth->execute()))
{
	print "Content-type: text/html\n\n";
	$tmpl->param(error_string => $dbh->errstr);
	print $tmpl->output;
	exit 1;
}
$sth->bind_columns(undef,\$id,\$name);
my @pull_down=();
while($sth->fetch())
{
	if($name eq "default" || $name eq "Default")
	{
		$default_user_id = $id;
	}

	my %pair = (id => $id, name => $name);
	push @pull_down, \%pair;
}
$tmpl->param(pull_down => \@pull_down);

# Show normal tables
foreach my $table (@normal_tables_by_userID)
{
	my @table_items = ();
	my $ary_ref = undef;
	if(defined($default_user_id))
	{
		$sql_str="select * from ".$table." where userID=".$default_user_id;
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			print "Content-type: text/html\n\n";
			$tmpl->param(error_string => $dbh->errstr);
			print $tmpl->output;
			exit 1;
		}
		
		$ary_ref = $sth->fetchrow_arrayref;
	}
	if(!defined($ary_ref))
	{
		$sql_str="select * from ".$table.get_only_one($db_conn);
		$sth=$dbh->prepare($sql_str);
		if(!defined($sth->execute()))
		{
			print "Content-type: text/html\n\n";
			$tmpl->param(error_string => $dbh->errstr);
			print $tmpl->output;
			exit 1;
		}
	}

	for(my $m=1;$m<$sth->{NUM_OF_FIELDS};$m++)
	{
		if(uc($sth->{NAME}->[$m]) ne uc("clusterID"))
		{
			my $default = "";
			if(defined($default_user_id) && defined($ary_ref) && exists $ary_ref->[$m])
			{
				$default = $ary_ref->[$m];
			}
			
			my %item = (id => $table."-".$sth->{NAME}->[$m],
				    name => $table."-".$sth->{NAME}->[$m],
				    title => $table."-".$sth->{NAME}->[$m],
				    display_name => $sth->{NAME}->[$m],
				    orig_id => "orig-".$table."-".$sth->{NAME}->[$m],
				    orig_name => "orig-".$table."-".$sth->{NAME}->[$m],
				    default => $default);
			push @table_items, \%item;
		}
	}
	$tmpl->param($table."_items" => \@table_items);
	$tmpl->param($table."-primary_key" => $sth->{NAME}->[0]);
	
}

$sth->finish();
$dbh->disconnect();


print "Content-type: text/html\n\n";
print $tmpl->output;
